vendorlicenses

package module
v0.0.0-...-9fb760c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2017 License: MIT Imports: 6 Imported by: 0

README

vendorlicenses Build Status Coverage Status codebeat badge Go Report Card GoDoc

vendorlicenses is a tool to check and concatenate licenses found on the vendor directory of Go programs.

To install it, run:

go get -u github.com/henvic/vendorlicenses/cmd/vendorlicenses

Usage:

$ vendorlicenses -h
Usage of vendorlicenses:
  -directory string
    	Directory to analyse (default ".")
  -list
    	List license filepaths
  -missing
    	List dependencies probably missing licenses

This tool is not appropriate for vetting licenses compliance, but to provide a concat tool for licenses similar to what is found on the legal submenus of consumer devices, such as mobile devices or cars media centers.

For vetting licensing compliance, consider using something like FOSSA or FOSSology instead.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type VendorLicenses

type VendorLicenses struct {
	Directory string
	// contains filtered or unexported fields
}

VendorLicenses parses the vendor directory to find licenses

func (*VendorLicenses) List

func (v *VendorLicenses) List() (list []string, err error)

List and load paths to license files on the vendor directory

func (*VendorLicenses) Missing

func (v *VendorLicenses) Missing() (missing []string, err error)

Missing licenses on a given vendor directory

func (*VendorLicenses) ReadAll

func (v *VendorLicenses) ReadAll() (legal []byte, err error)

ReadAll reads all licenses on the vendor directory

Directories

Path Synopsis
cmd
vendorlicenses command

Jump to